<?php

namespace Drupal\bible\Entity;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityPublishedTrait;

/**
 * Defines the Bible Book entity.
 *
 * @ingroup bible
 *
 * @ContentEntityType(
 *   id = "bible_book",
 *   label = @Translation("Bible Book"),
 *   base_table = "bible_book",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *     "uuid" = "uuid",
 *   },
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\Core\Entity\EntityListBuilder",
 *     "form" = {
 *       "default" = "Drupal\Core\Entity\ContentEntityForm",
 *       "add" = "Drupal\Core\Entity\ContentEntityForm",
 *       "edit" = "Drupal\Core\Entity\ContentEntityForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityForm",
 *     },
 *     "access" = "Drupal\Core\Entity\EntityAccessControlHandler",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *   },
 *   links = {
 *     "canonical" = "/bible/book/{bible_book}",
 *     "add-form" = "/bible/book/add",
 *     "edit-form" = "/bible/book/{bible_book}/edit",
 *     "delete-form" = "/bible/book/{bible_book}/delete",
 *     "collection" = "/admin/structure/bibles/books",
 *   },
 * )
 */
class BibleBook extends ContentEntityBase {
  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entityType) {
    $fields = parent::baseFieldDefinitions($entityType);

    $fields['code'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Code'))
      ->setDescription(t('The universal 3-character identifier for the book.'))
      ->setSettings([
        'max_length' => 255,
        'text_processing' => 0,
      ])
      ->setRequired(TRUE);

    $fields['bible'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Bible'))
      ->setDescription(t('The Bible entity this book belongs to.'))
      ->setSetting('target_type', 'bible')
      ->setRequired(TRUE);

    $fields['name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Name'))
      ->setDescription(t('The full name of the book.'))
      ->setSettings([
        'max_length' => 255,
        'text_processing' => 0,
      ]);

    $fields['shortname'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Abbreviation'))
      ->setDescription(t('The short name of the book.'))
      ->setSettings([
        'max_length' => 255,
        'text_processing' => 0,
      ]);

    $fields['number'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Book Number'))
      ->setDescription(t('The index position of the book.'))
      ->setSetting('unsigned', TRUE);

    $fields['chapters'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Chapter Count'))
      ->setDescription(t('The number of chapters in the book.'))
      ->setSetting('unsigned', TRUE);

    return $fields;
  }
}
