<?php
namespace Drupal\bible\Entity;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\user\EntityOwnerTrait;
use Drupal\Core\Entity\EntityChangedTrait;

/**
 * Defines the Bible Note entity.
 *
 * @ContentEntityType(
 *   id = "bible_note",
 *   label = @Translation("Bible Note"),
 *   base_table = "bible_note",
 *   entity_keys = {
 *     "id" = "id",
 *     "uuid" = "uuid",
 *     "uid" = "user",
 *     "label" = "title",
 *     "langcode" = "langcode",
 *   },
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\Core\Entity\EntityListBuilder",
 *     "form" = {
 *       "default" = "Drupal\Core\Entity\ContentEntityForm",
 *       "add" = "Drupal\Core\Entity\ContentEntityForm",
 *       "edit" = "Drupal\Core\Entity\ContentEntityForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityForm",
 *     },
 *     "access" = "Drupal\Core\Entity\EntityAccessControlHandler",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *   },
 *   links = {
 *     "canonical" = "/bible/note/{bible_note}",
 *     "add-form" = "/bible/note/add",
 *     "edit-form" = "/bible/note/{bible_note}/edit",
 *     "delete-form" = "/bible/note/{bible_note}/delete",
 *     "collection" = "/bible/note/list"
 *   },
 * )
 */
class BibleNote extends ContentEntityBase {
  use EntityOwnerTrait;
  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['user'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('User ID'))
      ->setDescription(t('The ID of the user who created the Bible Note.'))
      ->setSetting('target_type', 'user')
      ->setRequired(TRUE);

    $fields['bible'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Bible ID'))
      ->setDescription(t('The ID of the referenced Bible.'))
      ->setSetting('target_type', 'bible')
      ->setRequired(TRUE);

    $fields['verse'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Verse ID'))
      ->setDescription(t('The ID of the referenced Bible Verse.'))
      ->setSetting('target_type', 'bible_verse')
      ->setRequired(TRUE);

    $fields['public'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Public'))
      ->setDescription(t('A boolean indicating whether the Bible Note is public or private.'));

    $fields['title'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Title'))
      ->setDescription(t('The title of the Bible Note.'))
      ->setSetting('max_length', 255)
      ->setRequired(TRUE);

    $fields['body'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Body'))
      ->setDescription(t('The body text of the Bible Note.'));

    $fields['source'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Source'))
      ->setDescription(t('The source of the Bible Note.'))
      ->setSetting('max_length', 255);

    $fields['langcode'] = BaseFieldDefinition::create('language')
      ->setLabel(t('Language'))
      ->setDescription(t('The language code of the Bible Note.'));

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Updated'))
      ->setDescription(t('The time that the entity was last edited.'));

    return $fields;
  }

}
