<?php

namespace Drupal\bible\Entity;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;

/**
 * Defines the Bible Verse entity.
 *
 * @ContentEntityType(
 *   id = "bible_verse",
 *   label = @Translation("Bible Verse"),
 *   base_table = "bible_verse",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "verse",
 *     "uuid" = "uuid",
 *   },
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\Core\Entity\EntityListBuilder",
 *     "form" = {
 *       "default" = "Drupal\Core\Entity\ContentEntityForm",
 *       "add" = "Drupal\Core\Entity\ContentEntityForm",
 *       "edit" = "Drupal\Core\Entity\ContentEntityForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityForm",
 *     },
 *     "access" = "Drupal\Core\Entity\EntityAccessControlHandler",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *   },
 *   links = {
 *     "canonical" = "/bible/verse/{bible_verse}",
 *     "add-form" = "/bible/verse/add",
 *     "edit-form" = "/bible/verse/{bible_verse}/edit",
 *     "delete-form" = "/bible/verse/{bible_verse}/delete",
 *     "collection" = "/bible/verse/list"
 *   },
 *   field_ui_base_route = "entity.bible_verse.settings"
 * )
 */
class BibleVerse extends ContentEntityBase {
  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entityType) {
    $fields = parent::baseFieldDefinitions($entityType);

    $fields['bible'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Bible Reference'))
      ->setDescription(t('The reference to the Bible entity.'))
      ->setSetting('target_type', 'bible')
      ->setRequired(TRUE);

    $fields['book'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Book Reference'))
      ->setDescription(t('The reference to the Bible Book entity.'))
      ->setSetting('target_type', 'bible_book')
      ->setRequired(TRUE);

    $fields['chapter'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Chapter'))
      ->setDescription(t('The chapter number of the verse.'))
      ->setSetting('unsigned', TRUE);

    $fields['number'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Verse number'))
      ->setDescription(t('The verse number of the verse.'))
      ->setSetting('unsigned', TRUE);

    $fields['linemark'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Linemark'))
      ->setDescription(t('The linemark of the verse.'))
      ->setSettings([
        'max_length' => 255,
        'text_processing' => 0,
      ]);

    $fields['text'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Text'))
      ->setDescription(t('The text of the verse.'))
      ->setSetting('text_processing', 0);

    $fields['superscription'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Superscription'))
      ->setDescription(t('The superscription is used to add a prefix before the first verse of a chapter or Psalm.'))
      ->setSetting('text_processing', 0);

    $fields['subscription'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Subscription'))
      ->setDescription(t('The subscription is sometimes used to suffix a comment to the final verse of a book.'))
      ->setSetting('text_processing', 0);

    return $fields;
  }

}
