<?php

namespace Drupal\bible\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for the Bible entity type.
 */
final class BibleSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'bible.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'bible_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('bible.settings');
    // Make this a dropdown of Bible entities.
    // We could also add an isDefault() check to the Bible entity
    // but the setting storage should be global.
    $form['default_translation'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default Bible Translation'),
      '#default_value' => $config->get('default_translation'),
      '#description' => $this->t('Enter the default Bible translation to be used.'),
      '#required' => TRUE,
    ];

    $form['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Save'),
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->configFactory->getEditable('bible.settings')
      ->set('default_translation', $form_state->getValue('default_translation'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
